@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 from __future__ import print_function, with_statement
 from copy import copy
+from distutils.version import LooseVersion
 import os.path
 import shutil
 try:
@@ -9,6 +10,7 @@ except ImportError:
     import unittest
 
 from cms.test_utils.tmpdir import temp_dir
+import django
 
 from ..main import core, _make_settings
 from ..utils import work_in, captured_output
@@ -16,17 +18,23 @@ from ..utils import work_in, captured_output
 DEFAULT_ARGS = {
     'shell': False,
     'test': False,
+    'check': False,
+    'cms_check': False,
     'compilemessages': False,
     'makemessages': False,
     'makemigrations': False,
+    'squashmigrations': False,
     'pyflakes': False,
     'authors': False,
     'server': False,
     '--xvfb': '',
+    '--runner': None,
+    '--runner-options': None,
     '--nose-runner': False,
     '--simple-runner': False,
     '--cms': True,
     '--failfast': False,
+    '--merge': False,
     '<test-label>': ''
 }
 
@@ -100,6 +108,7 @@ class CommandTests(unittest.TestCase):
             with captured_output() as (out, err):
                 args = copy(DEFAULT_ARGS)
                 args['makemigrations'] = True
+                args['--merge'] = True
                 core(args, self.application)
                 self.assertTrue(os.path.exists(self.migration_file))
         self.assertTrue('Created 0001_initial.py' in err.getvalue())
@@ -121,6 +130,29 @@ class CommandTests(unittest.TestCase):
                 core(args, self.application)
                 self.assertTrue(os.path.exists(self.mofile))
 
+    @unittest.skipIf(LooseVersion(django.get_version()) < LooseVersion('1.7'),
+                     reason='check command available for Django 1.7+ only')
+    def test_check(self):
+        with work_in(self.basedir):
+            with captured_output() as (out, err):
+                shutil.copy(self.poexample, self.pofile)
+                args = copy(DEFAULT_ARGS)
+                args['check'] = True
+                core(args, self.application)
+            self.assertEqual(len(out.getvalue()), 0)
+
+    def test_cms_check(self):
+        with work_in(self.basedir):
+            with captured_output() as (out, err):
+                shutil.copy(self.poexample, self.pofile)
+                args = copy(DEFAULT_ARGS)
+                args['cms_check'] = True
+                args['--migrate'] = False
+                core(args, self.application)
+            self.assertTrue('Installation okay' in out.getvalue())
+            self.assertFalse('[WARNING]' in out.getvalue())
+            self.assertFalse('[ERROR]' in out.getvalue())
+
     def test_pyflakes(self):
         with work_in(self.basedir):
             with captured_output() as (out, err):
